@@ -27,7 +27,8 @@ class MonumentNameToImage:
             "sewer_display_name" : "sewer.png",
             "oil_rig_small" : "small_oil_rig.png",
             "large_oil_rig" : "large_oil_rig.png",
-            "underwater_lab" : "underwater_lab.png"
+            "underwater_lab" : "underwater_lab.png",
+            "AbandonedMilitaryBase" : "desert_base.png"
         }
 
         self.overrideImages = overrideImages
